==> n3_sdk-1.3.1r03.zip: n3_sdk-1.3.1/lib/component/n3c_ajax-1.0.0-min.js <==

N3C.XMLIterator=Class.cast({Static:{parse:function(s,m){if(DOMParser){m=m||"text/xml";var d=new DOMParser().parseFromString(s,m);if(d.documentElement.nodeName!=="parsererror"){return new this(d);}}
return null;}},_r:null,_t:null,_n:null,newInstance:function(node){this._r=node;this._t=node.childNodes[0];},load:function(n){var nodes=this._r.getElementsByTagName(n);if(!nodes||nodes.length===0){throw new Error("Not found node name ["+n+"]");}
this._t=nodes[0].childNodes[0];return this;},reset:function(){this._t=this._r.childNodes[0];this._n=null;},hasNext:function(n){for(var node=this._t;node!=null;node=node.nextSibling){if(n&&n!=node.nodeName){continue;}
var type=node.nodeType;if(type===1){this._n=node;return true;}}
return false;},next:function(n){if(!this._n&&!this.hasNext(n)){return null;}
this._t=this._n.nextSibling;return this;},getTargetText:function(){if(!this._n){return null;}
var type=this._n.nodeType;var t="";if(type===1){if(this._n.firstChild){t=this._n.firstChild.nodeValue;}}
else if(type===3){t=this._n.nodeValue;}
return t.trim();},getTargetName:function(){if(!this._n){return null;}
var type=this._n.nodeType;var t="";if(type===1){t=this._n.nodeName;}
return t;},getAttribute:function(n){if(!this._n){return null;}
return this._n.getAttribute(n);},getChildren:function(){if(this._n){return new N3C.XMLIterator(this._n);}
else{return null;}}});N3C.HttpConnection=Class.cast({Const:{CM_GET:"GET",CM_POST:"POST",REX_SPLIT_URI:new RegExp("^(?:([^:\\/?#]+:))?(?:\\/\\/([^\\/?#]*))?([^?#]*)(?:\\?([^#]*))?(?:#(.*))?")},_con:null,_url:null,_method:null,_request:null,_listener:null,_ct:null,_quit:false,_rhs:null,_params:null,newInstance:function(url,method,request,ct,l,params){this._url=url;this._method=method;this._ct=ct;this._params=params;this._rhs={};if(!Class.interfaceOf(l,N3C.HttpConnection.AccessCompletedListener)){throw new Error("Listener must implement \"N3C.HttpConnection.AccessCompletedListener\" interface.");}
this._listener=l;var cmjv=N3C.getBrowserCoreMajor();var cmnv=N3C.getBrowserCoreMinor();if(request instanceof Document&&N3C.isBrowserCore(N3C.BCORE_WEBKIT)&&(cmjv<526||(cmjv===526&&cmnv<8))){this._preProcUrlEncode(request.documentElement);}
this._request=request;},connect:function(async){var con=null;if(window.XMLHttpRequest){con=this._con=new XMLHttpRequest();}else{throw new Error("cannot connect to server!");}
var _this=this;con.addEventListener("readystatechange",function(){if(!_this){return;}
if(_this._quit){return;}
if(con.readyState===4){var status=_this.getStatus();var avail=status!=-1&&(status===0||(status>=200&&status<=299));N3C.requestDisplayReady(function(){_this._listener.accessCompleted(avail,_this,_this._params);_this.quit=true;});}
if(_this._quit){_this=null;}},true);con.open(this._method,this._url,async);if(con.setRequestHeader){var xrw="X-Requested-With";if(this._maySameDomain()&&!this._rhs[xrw]){con.setRequestHeader(xrw,"XMLHttpRequest");}
if(this._ct){con.setRequestHeader("Content-Type",this._ct);}
else if(this._method==N3C.HttpConnection.CM_POST){con.setRequestHeader("Content-Type","application/x-www-form-urlencoded");}
if(this._rhs){for(var h in this._rhs){con.setRequestHeader(h,this._rhs[h]);}}}
con.send(this._request);},quit:function(){var con=this._con;if(con){con.abort();}
this._quit=true;this._con=null;},getResponseHeader:function(h){return this._con?this._con.getResponseHeader(h):"";},getAllResponseHeaders:function(){return this._con?this._con.getAllResponseHeaders():"";},getStatus:function(){return this._con?this._con.status:-1;},getRawResponse:function(){return this._con?this._con.responseText:"";},getXmlIterator:function(){return this._con?new N3C.XMLIterator(this._con.responseXML):null;},getJsonObject:function(){return this._con?JSON.parse(this._con.responseText):null;},setRequestHeader:function(k,v){this._rhs[k]=v;return this;},_maySameDomain:function(){var url=this._url;var r=N3C.HttpConnection.REX_SPLIT_URI.exec(url);if(r){var l=window.location;var scheme0=l.protocol;var host0=l.host;var scheme1=r[1];var host1=r[2];return(!scheme1&&!host1)||(scheme0===scheme1&&host0===host1);}
return true;},_preProcUrlEncode:function(e){if(e.nodeType==3){var v=new N3C.String(e.data).replaceAllStr("&","&amp;").replaceAllStr("<","&lt;").replaceAllStr(">","&gt;").toString();e.data=v;}else{var child=e.firstChild;while(child){this._preProcUrlEncode(child);child=child.nextSibling;}}}});N3C.HttpConnection.AccessCompletedListener={accessCompleted:null};

==> n3_sdk-1.3.3r03.zip: n3_sdk-1.3.3/lib/component/n3c_ajax-1.0.0-min.js <==

N3C.XMLIterator=Class.cast({Static:{parse:function(s,m){if(DOMParser){m=m||"text/xml";var d=new DOMParser().parseFromString(s,m);if(d.documentElement.nodeName!=="parsererror"){return new this(d);}}
return null;}},_r:null,_t:null,_n:null,newInstance:function(node){this._r=node;this._t=node.childNodes[0];},load:function(n){var nodes=this._r.getElementsByTagName(n);if(!nodes||nodes.length===0){throw new Error("Not found node name ["+n+"]");}
this._t=nodes[0].childNodes[0];return this;},reset:function(){this._t=this._r.childNodes[0];this._n=null;},hasNext:function(n){for(var node=this._t;node!=null;node=node.nextSibling){if(n&&n!=node.nodeName){continue;}
var type=node.nodeType;if(type===1){this._n=node;return true;}}
return false;},next:function(n){if(!this._n&&!this.hasNext(n)){return null;}
this._t=this._n.nextSibling;return this;},getTargetText:function(){if(!this._n){return null;}
var type=this._n.nodeType;var t="";if(type===1){if(this._n.firstChild){t=this._n.firstChild.nodeValue;}}
else if(type===3){t=this._n.nodeValue;}
return t.trim();},getTargetName:function(){if(!this._n){return null;}
var type=this._n.nodeType;var t="";if(type===1){t=this._n.nodeName;}
return t;},getAttribute:function(n){if(!this._n){return null;}
return this._n.getAttribute(n);},getChildren:function(){if(this._n){return new N3C.XMLIterator(this._n);}
else{return null;}}});N3C.HttpConnection=Class.cast({Const:{CM_GET:"GET",CM_POST:"POST",REX_SPLIT_URI:new RegExp("^(?:([^:\\/?#]+:))?(?:\\/\\/([^\\/?#]*))?([^?#]*)(?:\\?([^#]*))?(?:#(.*))?"),AccessCompletedListener:{accessCompleted:null}},_con:null,_url:null,_method:null,_request:null,_listener:null,_ct:null,_quit:false,_rhs:null,_params:null,newInstance:function(url,method,request,ct,l,params){this._url=url;this._method=method;this._ct=ct;this._params=params;this._rhs={};if(!Class.interfaceOf(l,N3C.HttpConnection.AccessCompletedListener)){throw new Error("Listener must implement \"N3C.HttpConnection.AccessCompletedListener\" interface.");}
this._listener=l;this._request=request;},connect:function(async){var con=null;if(window.XMLHttpRequest){con=this._con=new XMLHttpRequest();}else{throw new Error("cannot connect to server!");}
var _this=this;con.addEventListener("readystatechange",function(){if(!_this){return;}
if(_this._quit){return;}
if(con.readyState===4){var status=_this.getStatus();var avail=status!=-1&&(status===0||(status>=200&&status<=299));N3C.requestDisplayReady(function(){_this._listener.accessCompleted(avail,_this,_this._params);_this.quit=true;});}
if(_this._quit){_this=null;}},true);con.open(this._method,this._url,async);if(con.setRequestHeader){var xrw="X-Requested-With";if(this._maySameDomain()&&!this._rhs[xrw]){con.setRequestHeader(xrw,"XMLHttpRequest");}
if(this._ct){con.setRequestHeader("Content-Type",this._ct);}
else if(this._method==N3C.HttpConnection.CM_POST){con.setRequestHeader("Content-Type","application/x-www-form-urlencoded");}
if(this._rhs){for(var h in this._rhs){con.setRequestHeader(h,this._rhs[h]);}}}
con.send(this._request);},quit:function(){var con=this._con;if(con){con.abort();}
this._quit=true;this._con=null;},getResponseHeader:function(h){return this._con?this._con.getResponseHeader(h):"";},getAllResponseHeaders:function(){return this._con?this._con.getAllResponseHeaders():"";},getStatus:function(){return this._con?this._con.status:-1;},getRawResponse:function(){return this._con?this._con.responseText:"";},getXmlIterator:function(){return this._con?new N3C.XMLIterator(this._con.responseXML):null;},getJsonObject:function(){return this._con?JSON.parse(this._con.responseText):null;},setRequestHeader:function(k,v){this._rhs[k]=v;return this;},_maySameDomain:function(){var url=this._url;var r=N3C.HttpConnection.REX_SPLIT_URI.exec(url);if(r){var l=window.location;var scheme0=l.protocol;var host0=l.host;var scheme1=r[1];var host1=r[2];return(!scheme1&&!host1)||(scheme0===scheme1&&host0===host1);}
return true;},_preProcUrlEncode:function(e){if(e.nodeType==3){var v=new N3C.StringBuilder(e.data).replaceAll("&","&amp;").replaceAll("<","&lt;").replaceAll(">","&gt;").toString();e.data=v;}
else{var child=e.firstChild;while(child){this._preProcUrlEncode(child);child=child.nextSibling;}}}});
